@@ -29,8 +29,9 @@ typedef struct {
 int utf8_to_16(char *text, wchar_t *wtext, int wlen);
 int utf16_to_8(wchar_t *in, char *out, int outN);
 inline void *GDK_DISPLAY() { return NULL;}
-typedef wchar_t unich_t;
+//typedef wchar_t unich_t;
 #define _L(x)      L ## x
+#pragma execution_character_set("utf-8")
 #else
 typedef char unich_t;
 void unix_exec(char *fmt,...);
